import { Container, DefaultProperties, Input as InputImpl, Text } from '@react-three/uikit';
import React, { useMemo, useState } from 'react';
import { colors } from './theme';
import { Signal, computed } from '@preact/signals-core';
export function Input({ panelMaterialClass, multiline, value, defaultValue, onValueChange, tabIndex, disabled = false, placeholder, ...props }) {
    const [internal, setInternal] = useState(null);
    const placeholderOpacity = useMemo(() => {
        if (internal == null) {
            return undefined;
        }
        if (internal.value instanceof Signal) {
            const signal = internal.value;
            return computed(() => (signal.value.length > 0 ? 0 : undefined));
        }
        return internal.value.length > 0 ? 0 : undefined;
    }, [internal]);
    return (React.createElement(Container, { height: 40, positionType: "relative", overflow: "hidden", ...props },
        React.createElement(DefaultProperties, { fontSize: 14, height: "100%", width: "100%", border: 1, paddingX: 12, paddingY: 8, lineHeight: 1.43, opacity: disabled ? 0.5 : undefined, backgroundOpacity: disabled ? 0.5 : undefined },
            React.createElement(InputImpl, { ref: setInternal, borderRadius: 6, backgroundColor: colors.background, borderColor: colors.input, focus: {
                    borderColor: colors.ring,
                }, panelMaterialClass: panelMaterialClass, multiline: multiline, value: value, defaultValue: defaultValue, onValueChange: onValueChange, tabIndex: tabIndex, disabled: disabled }),
            placeholder != null && (React.createElement(Text, { color: colors.mutedForeground, opacity: placeholderOpacity, borderOpacity: 0, inset: 0, positionType: "absolute" }, placeholder)))));
}
